@@ -11,6 +11,7 @@ extern "C" {
 #include <dpkg/dpkg.h>
 #include <dpkg/dpkg-db.h>
 #include <dpkg/db-fsys.h>
+#include <dpkg/fsys.h>
 #include <dpkg/pkg-array.h>
 #include <dpkg/pkg-list.h>
 #include <dpkg/pkg-show.h>
@@ -19,11 +20,16 @@ extern "C" {
 #include "dpkg.h"
 #include "usr_merge.h"
 
+#ifndef LIBDPKG_HAS_NEW_FHFF
+#define FHFF_NO_COPY	FHFF_NOCOPY
+#endif
+
 /*
 https://www.dpkg.org/doc/libdpkg/structpkginfo.html
 */
 
-void dpkg_start() {
+void dpkg_start(const string& root_dir) {
+	dpkg_fsys_set_dir(root_dir == "/" ? "" : root_dir.c_str());
 	dpkg_program_init("cruft");
 	modstatdb_open(msdbrw_readonly);
 }
@@ -39,7 +45,7 @@ int query(const char *path)
 	ensure_diversions();
 
 	struct fsys_namenode *namenode;
-	namenode = fsys_hash_find_node(path, FHFF_NOCOPY);
+	namenode = fsys_hash_find_node(path, FHFF_NO_COPY);
 
 	if (namenode->divert) {
 	        cout << namenode->divert->pkgset->name << '\n';
@@ -105,7 +111,7 @@ static void callback(const char *filename, const char *filetype)
 }
 #endif
 
-int read_dpkg(vector<string>& packages, vector<string>& output, bool print_csv)
+int read_dpkg(vector<string>& packages, vector<string>& output, bool print_csv, const string& root_dir)
 {
 	struct pkg_array array;
 	struct pkginfo *pkg;
@@ -142,6 +148,8 @@ int read_dpkg(vector<string>& packages, vector<string>& output, bool print_csv)
 	ensure_diversions();
 	ensure_allinstfiles_available_quiet();
 
+	auto root_dir_length = root_dir.length()-1;
+
 	for (int i = 0; i < array.n_pkgs; i++) {
 		pkg = array.pkgs[i];
 		if (pkg->status == PKG_STAT_INSTALLED || pkg->status == PKG_STAT_CONFIGFILES) {
@@ -169,7 +177,7 @@ int read_dpkg(vector<string>& packages, vector<string>& output, bool print_csv)
 			for (const auto& suffix: suffixes) {
 				string control = control_ + suffix;
 				if (stat(control.c_str(), &buffer) == 0) {
-					output.emplace_back(control);
+					output.emplace_back(control.substr(root_dir_length));
 				}
 			}
 #endif
