@@ -18,6 +18,7 @@ static void read_one_filter(const string& glob_filename, const string& package,
 	for (string glob_line; getline(glob_file, glob_line);)
 	{
 		if (glob_line.empty()) continue;
+		if (glob_line.front() == '#') continue;
 		if (glob_line.front() == '/') {
 			if (debug) cerr << package << " " << glob_line << endl;
 			globs.emplace_back(package, usr_merge(glob_line));
@@ -29,7 +30,7 @@ int read_filters(const string& dir, const string& ruleset_file, const vector<str
 {
 	bool debug=getenv("DEBUG") != nullptr;
 
-	if (debug) cerr << "READING UPERCASE GLOBS IN " << dir << endl;
+	if (debug) cerr << "READING UPPERCASE GLOBS IN " << dir << endl;
 	DIR *dp;
 	struct dirent *dirp;
 	if((dp = opendir(dir.c_str())) == nullptr) {
@@ -70,6 +71,8 @@ int read_filters(const string& dir, const string& ruleset_file, const vector<str
 	{
 		if (glob_line.empty())
 			continue;
+		if (glob_line.front() == '#')
+			continue;
 		if (glob_line.front() == '/') {
 			if (keep) {
 				globs.emplace_back(package, usr_merge(glob_line));
