@@ -9,25 +9,9 @@
 
 #include "locate.h"
 #include "python.h"
+#include "read_ignores.h"
 
-static void read_ignores(vector<string>& ignores, const string& ignore_path)
-{
-	ifstream ignore_file(ignore_path);
-	if (!ignore_file.is_open())
-		ignore_file.open("/usr/share/cruft/ignore");
-
-	for (string ignore_line; getline(ignore_file,ignore_line);)
-	{
-		if (ignore_line.empty()) continue;
-		if (ignore_line.front() == '/') {
-			if (ignore_line.back() != '/')
-				ignore_line += "/";
-			ignores.emplace_back(std::move(ignore_line));
-		}
-	}
-}
-
-int read_locate(vector<string>& fs, const string& ignore_path)
+int read_locate(vector<string>& fs, const string& ignore_path, const string& root_dir)
 {
 	bool debug=getenv("DEBUG") != nullptr;
 
